.. scikit-ci-addons documentation master file, created by
   sphinx-quickstart on Thu Oct 27 04:37:15 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to scikit-ci-addons's documentation!
============================================

scikit-ci-addons is a command line tool and a set of scripts useful to install
prerequisites for building Python extension on CI services.

Contents:

.. toctree::
   :maxdepth: 2
   :caption: User guide

   installation
   usage
   addons
   contributing
   authors
   history

.. toctree::
   :maxdepth: 2
   :caption: For maintainers

   make_a_release


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Resources
=========

* Free software: Apache Software license
* Documentation: http://scikit-ci-addons.readthedocs.org
* Source code: https://github.com/scikit-build/scikit-ci-addons
* Mailing list: https://groups.google.com/forum/#!forum/scikit-build


